@@ -1,6 +1,6 @@
 var indexSectionsWithContent =
 {
-  0: "abcdefghijklmnopqrstuv~",
+  0: "abcdefghijklmnopqrstuvwy~",
   1: "b",
   2: "b",
   3: "abcdefgilmnopqrstuv~",
@@ -8,7 +8,7 @@ var indexSectionsWithContent =
   5: "b",
   6: "be",
   7: "b",
-  8: "cdfhlort"
+  8: "bcdefhlmort"
 };
 
 var indexSectionNames =
